==> haskell-data-fix-0.3.2-102-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-fix.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-fix
version:              0.3.2
visibility:           public
id:                   data-fix-0.3.2-JeLT2b5tMLZJ0S1cVDwyn1
key:                  data-fix-0.3.2-JeLT2b5tMLZJ0S1cVDwyn1
license:              BSD-3-Clause
maintainer:           <anton.kholomiov@gmail.com>
author:               Anton Kholomiov, Edward Kmett, Oleg Grenrus
stability:            Experimental
homepage:             https://github.com/spell-music/data-fix
synopsis:             Fixpoint data types
description:
    Fixpoint types and recursion schemes. If you define your AST as
    fixpoint type, you get fold and unfold operations for free.

    Thanks for contribution to: Matej Kollar, Herbert Valerio Riedel

category:             Data
abi:                  8ef45a3a628ccdfde09cfa15ec209b59
exposed:              True
exposed-modules:      Data.Fix
import-dirs:          /usr/lib/ghc-9.2.8/site-local/data-fix-0.3.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/data-fix-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-fix
hs-libraries:         HSdata-fix-0.3.2-JeLT2b5tMLZJ0S1cVDwyn1
depends:
    base-4.16.4.0 deepseq-1.4.6.1
    hashable-1.4.3.0-4gqtyFKn8Wu9OwsZtyYGdt

haddock-interfaces:   /usr/share/doc/haskell-data-fix/html/data-fix.haddock
haddock-html:         /usr/share/doc/haskell-data-fix/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-fix-0.3.2-107-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-fix.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-fix
version:              0.3.2
visibility:           public
id:                   data-fix-0.3.2-FGkTCFWnE3E5Wykr5tvlhN
key:                  data-fix-0.3.2-FGkTCFWnE3E5Wykr5tvlhN
license:              BSD-3-Clause
maintainer:           <anton.kholomiov@gmail.com>
author:               Anton Kholomiov, Edward Kmett, Oleg Grenrus
stability:            Experimental
homepage:             https://github.com/spell-music/data-fix
synopsis:             Fixpoint data types
description:
    Fixpoint types and recursion schemes. If you define your AST as
    fixpoint type, you get fold and unfold operations for free.

    Thanks for contribution to: Matej Kollar, Herbert Valerio Riedel

category:             Data
abi:                  246b7267a22fec41f4fc711f65c89864
exposed:              True
exposed-modules:      Data.Fix
import-dirs:          /usr/lib/ghc-9.2.8/site-local/data-fix-0.3.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/data-fix-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-fix
hs-libraries:         HSdata-fix-0.3.2-FGkTCFWnE3E5Wykr5tvlhN
depends:
    base-4.16.4.0 deepseq-1.4.6.1
    hashable-1.4.4.0-DtL5AH6y1if92iaAq0qoKj

haddock-interfaces:   /usr/share/doc/haskell-data-fix/html/data-fix.haddock
haddock-html:         /usr/share/doc/haskell-data-fix/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
